/*
 * Plasma applet to display application window menus
 *
 * Copyright 2010 Canonical Ltd.
 *
 * Authors:
 * - Aurélien Gâteau <aurelien.gateau@canonical.com>
 *
 * License: GPL v3
 */
#ifndef MENUWIDGET_H
#define MENUWIDGET_H

// Qt
#include <QGraphicsSceneMouseEvent>

// KDE
#include <Plasma/Applet>
#include <Plasma/ToolButton>

class QGraphicsLinearLayout;
class QMenu;

class MenuButton : public Plasma::ToolButton
{
    Q_OBJECT
public:
    MenuButton(QGraphicsWidget* parent, QMenu* menu)
    : Plasma::ToolButton(parent)
    , mMenu(menu)
    {}

    QMenu* menu() const { return mMenu; }

protected:
    // Let the event propagate so that the applet context menu is shown
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
    {
        event->ignore();
    }

private:
    QMenu* mMenu;
};


class MenuWidget : public QGraphicsWidget
{
    Q_OBJECT
public:
    MenuWidget(Plasma::Applet* applet);
    void setMenu(QMenu*);
    void activate();

protected:
    virtual bool eventFilter(QObject*, QEvent*);

private Q_SLOTS:
    void slotButtonClicked();
    void showMenu(MenuButton*);
    void checkMousePosition();
    void slotAboutToHideMenu();
    void createButtons();

private:
    Plasma::Applet* mApplet;
    QGraphicsLinearLayout* mLayout;
    QTimer* mMouseChecker;
    QTimer* mCreateButtonsTimer;
    QMenu* mRootMenu;
    QList<MenuButton*> mMenuButtonList;
    MenuButton* mCurrentButton;

    void showNextPrevMenu(bool next);
    void createButton(const QString& text, QMenu*);

    bool rootMenuEventFilter(QEvent*);
    bool subMenuEventFilter(QMenu*, QEvent*);
};
#endif /* MENUWIDGET_H */
