/*
 * Plasma applet to display application window menus
 *
 * Copyright 2010 Canonical Ltd.
 *
 * Authors:
 * - Aurélien Gâteau <aurelien.gateau@canonical.com>
 *
 * License: GPL v3
 */
// Self
#include "menuutilstest.h"

// Qt
#include <QMenu>
#include <QtTest>
#include <QVariant>

// KDE
#include <qtest_kde.h>
#include <KDebug>

#include <qjson/serializer.h>

// Local
#include "menuutils.h"

QTEST_KDEMAIN(MenuUtilsTest, GUI)

void cheapNormalize(QString* text)
{
    text->replace(" ", "");
    text->replace("\n", "");
}

void MenuUtilsTest::testVariantFromMenu()
{
    QAction* action;
    QMenu menu;
    QAction* file = menu.addAction("File");
    QMenu* subMenu = new QMenu;
    file->setMenu(subMenu);
    action = subMenu->addAction("New");
    action->setShortcut(Qt::Key_Ctrl | Qt::Key_Q);
    subMenu->addSeparator();
    subMenu->addAction("Quit");

    QVariant outputVariant = MenuUtils::variantFromMenu(&menu);
    QJson::Serializer serializer;

    QString output = QString::fromUtf8(serializer.serialize(outputVariant));

    QString expected =
    "{"
        "\"submenu\" : ["
            "{"
                "\"label\" : \"File\","
                "\"submenu\" : ["
                    "{ \"label\" : \"New\" } ,"
                    "{ \"separator\" : true } ,"
                    "{ \"label\" : \"Quit\" }"
                "]"
            "}"
        "]"
    "}";

    cheapNormalize(&output);
    cheapNormalize(&expected);

    QCOMPARE(output, expected);
}
